@@ -688,10 +688,9 @@ _ukui_panel_applet_frame_update_size_hints (UkuiPanelAppletFrame *frame,
 				value = screen_width - 195 -200;
 			}
 			else {
-				if (size_hints[i] > value && value > 400) {
+				if (size_hints[i] > (value-200) && value > 400) {
 
-                                        value=value-180-g_settings_get_int(settings, "launcher-nums")*40;
-					size_hints[i] = value;
+					size_hints[i] = screen_width - 195 -g_settings_get_int(settings, "launcher-nums")*30-100 - (g_settings_get_int(settings, "applet-nums")-2)*40;
 
 				}
 			}
